@@ -33,8 +33,8 @@
 #include "documentcatalog.h"
 #include "document.h"
 #include "directory.h"
-#include "status.h"
-#include "match.h"
+#include <status.h>
+#include <match.h>
 #include "actionopendocument.h"
 
 K_EXPORT_COMPONENT_FACTORY( katapult_documentcatalog,
