@@ -27,7 +27,7 @@
 #include <tqptrlist.h>
 #include <tqdir.h>
 
-#include "katapultcatalog.h"
+#include <katapultcatalog.h>
 
 class TQWidget;
 class Document;
